@@ -750,9 +750,9 @@ destroy_applet( GtkWidget *widget, ProgressData *battstat )
   g_object_unref( G_OBJECT(battstat->status) );
   g_object_unref( G_OBJECT(battstat->percent) );
 
-  g_free( battstat );
-
   static_global_teardown (battstat);
+
+  g_free (battstat);
 }
 
 /* Common function invoked by the 'Help' context menu item and the 'Help'
@@ -812,15 +812,11 @@ about_cb( GtkAction *action, ProgressData *battstat )
     NULL
    };
 
-  char copyright[] = \
-    "Copyright \xc2\xa9 2012-2018 MATE developers\n"
-    "Copyright \xc2\xa9 2002-2005 Free Software Foundation and others\n"
-    "Copyright \xc2\xa9 2000 The Gnulix Society";
-
   const gchar *documenters[] = {
     "J\xC3\xB6rgen Pehrson <jp@spektr.eu.org>",
     "Trevor Curtis <tcurtis@somaradio.ca>",
     "Davyd Madeley <davyd@madeley.id.au>",
+    N_("MATE Documentation Team"),
     NULL
   };
 
@@ -830,9 +826,18 @@ about_cb( GtkAction *action, ProgressData *battstat )
 		    /* true */ _("upower backend enabled.") :
 			/* false */ _("Legacy backend enabled."));
 
+#ifdef ENABLE_NLS
+  const char **p;
+  for (p = documenters; *p; ++p)
+    *p = _(*p);
+#endif
+
   gtk_show_about_dialog( NULL,
+    "title",               _("About Battery Charge Monitor"),
     "version",             VERSION,
-    "copyright",           copyright,
+    "copyright",           _("Copyright \xc2\xa9 2000 The Gnulix Society\n"
+                             "Copyright \xc2\xa9 2002-2005 Free Software Foundation and others\n"
+                             "Copyright \xc2\xa9 2012-2019 MATE developers"),
     "comments",            comments,
     "authors",             authors,
     "documenters",         documenters,
