@@ -19,10 +19,15 @@
  * Authors : Carlos Garca Campos <carlosgc@gnome.org>
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <cpufreq.h>
 #include <stdlib.h>
+#include <linux/version.h>
 
 #include "cpufreq-selector-libcpufreq.h"
 
@@ -38,8 +43,15 @@ static gboolean cpufreq_selector_libcpufreq_set_governor  (CPUFreqSelector
 
 G_DEFINE_TYPE (CPUFreqSelectorLibcpufreq, cpufreq_selector_libcpufreq, CPUFREQ_TYPE_SELECTOR)
 
-typedef struct cpufreq_policy                CPUFreqPolicy;
+#ifdef HAVE_GET_FREQUENCIES
+typedef struct cpufreq_frequencies CPUFreqFrequencyList;
+#define cpufreq_get_available_frequencies(cpu) cpufreq_get_frequencies ("available", cpu)
+#define cpufreq_put_available_frequencies(first) cpufreq_put_frequencies (first)
+#else
 typedef struct cpufreq_available_frequencies CPUFreqFrequencyList;
+#endif
+
+typedef struct cpufreq_policy                CPUFreqPolicy;
 typedef struct cpufreq_available_governors   CPUFreqGovernorList;
 
 static void
