@@ -165,13 +165,13 @@ static void mateweather_dialog_create(MateWeatherDialog* dialog)
   GtkWidget *cond_apparent_lbl;
   GtkWidget *cond_sunrise_lbl;
   GtkWidget *cond_sunset_lbl;
-  GtkWidget *cond_frame_alignment;
+  GtkWidget *cond_vbox;
   GtkWidget *current_note_lbl;
   GtkWidget *forecast_note_lbl;
   GtkWidget *radar_note_lbl;
   GtkWidget *radar_vbox;
   GtkWidget *radar_link_btn;
-  GtkWidget *radar_link_alignment;
+  GtkWidget *radar_link_box;
   GtkWidget *forecast_hbox;
   GtkWidget *ebox;
   GtkWidget *scrolled_window;
@@ -392,14 +392,16 @@ static void mateweather_dialog_create(MateWeatherDialog* dialog)
   gtk_label_set_justify (GTK_LABEL (priv->cond_sunset), GTK_JUSTIFY_LEFT);
   gtk_label_set_xalign (GTK_LABEL (priv->cond_sunset), 0.0);
 
-  cond_frame_alignment = gtk_alignment_new (0.5, 0, 1, 0);
-  gtk_widget_show (cond_frame_alignment);
-  gtk_box_pack_end (GTK_BOX (cond_hbox), cond_frame_alignment, FALSE, FALSE, 0);
-  gtk_container_set_border_width (GTK_CONTAINER (cond_frame_alignment), 2);
+  cond_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
+  gtk_widget_set_valign (cond_vbox, GTK_ALIGN_START);
+  gtk_widget_set_vexpand (cond_vbox, TRUE);
+  gtk_widget_show (cond_vbox);
+  gtk_box_pack_end (GTK_BOX (cond_hbox), cond_vbox, FALSE, FALSE, 0);
+  gtk_container_set_border_width (GTK_CONTAINER (cond_vbox), 2);
 
   priv->cond_image = gtk_image_new_from_icon_name ("stock-unknown", GTK_ICON_SIZE_BUTTON);
   gtk_widget_show (priv->cond_image);
-  gtk_container_add (GTK_CONTAINER (cond_frame_alignment), priv->cond_image);
+  gtk_container_add (GTK_CONTAINER (cond_vbox), priv->cond_image);
 
   current_note_lbl = gtk_label_new (_("Current Conditions"));
   gtk_widget_show (current_note_lbl);
@@ -463,16 +465,18 @@ static void mateweather_dialog_create(MateWeatherDialog* dialog)
 
       gtk_container_add (GTK_CONTAINER (ebox), priv->radar_image);
 
-      radar_link_alignment = gtk_alignment_new (0.5, 0.5, 0, 0);
-      gtk_widget_show (radar_link_alignment);
-      gtk_box_pack_start (GTK_BOX (radar_vbox), radar_link_alignment, FALSE, FALSE, 0);
+      radar_link_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+      gtk_widget_set_halign (radar_link_box, GTK_ALIGN_CENTER);
+      gtk_widget_set_hexpand (radar_link_box, TRUE);
+      gtk_widget_show (radar_link_box);
+      gtk_box_pack_start (GTK_BOX (radar_vbox), radar_link_box, FALSE, FALSE, 0);
 
       radar_link_btn = gtk_button_new_with_mnemonic (_("_Visit Weather.com"));
       set_access_namedesc (radar_link_btn, _("Visit Weather.com"), _("Click to Enter Weather.com"));
       gtk_widget_set_size_request (radar_link_btn, 450, -2);
       gtk_widget_show (radar_link_btn);
       if (!g_settings_get_boolean (gw_applet->settings, "use-custom-radar-url"))
-          gtk_container_add (GTK_CONTAINER (radar_link_alignment), radar_link_btn);
+          gtk_container_add (GTK_CONTAINER (radar_link_box), radar_link_btn);
 
       g_signal_connect (G_OBJECT (radar_link_btn), "clicked",
                         G_CALLBACK (link_cb), NULL);
@@ -502,6 +506,52 @@ static PangoFontDescription* get_system_monospace_font(void)
     return desc;
 }
 
+static void
+override_widget_font (GtkWidget            *widget,
+                      PangoFontDescription *font)
+{
+    static gboolean provider_added = FALSE;
+    static GtkCssProvider *provider;
+    gchar          *css;
+    gchar          *family;
+    gchar          *weight;
+    const gchar    *style;
+    gchar          *size;
+
+    family = g_strdup_printf ("font-family: %s;", pango_font_description_get_family (font));
+
+    weight = g_strdup_printf ("font-weight: %d;", pango_font_description_get_weight (font));
+
+    if (pango_font_description_get_style (font) == PANGO_STYLE_NORMAL)
+        style = "font-style: normal;";
+    else if (pango_font_description_get_style (font) == PANGO_STYLE_ITALIC)
+        style = "font-style: italic;";
+    else
+        style = "font-style: oblique;";
+
+    size = g_strdup_printf ("font-size: %d%s;",
+                            pango_font_description_get_size (font) / PANGO_SCALE,
+                            pango_font_description_get_size_is_absolute (font) ? "px" : "pt");
+    if (!provider_added)
+        provider = gtk_css_provider_new ();
+
+    gtk_widget_set_name(GTK_WIDGET(widget), "MateWeatherAppletTextView");
+    css = g_strdup_printf ("#MateWeatherAppletTextView { %s %s %s %s }", family, weight, style, size);
+    gtk_css_provider_load_from_data (provider, css, -1, NULL);
+
+    if (!provider_added) {
+        gtk_style_context_add_provider_for_screen (gtk_widget_get_screen (widget),
+                                                   GTK_STYLE_PROVIDER (provider),
+                                                   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+        provider_added = TRUE;
+    }
+
+    g_free (css);
+    g_free (family);
+    g_free (weight);
+    g_free (size);
+}
+
 void mateweather_dialog_update(MateWeatherDialog* dialog)
 {
     MateWeatherDialogPrivate *priv;
@@ -542,7 +592,7 @@ void mateweather_dialog_update(MateWeatherDialog* dialog)
     if (gw_applet->mateweather_pref.location->zone_valid) {
 	font_desc = get_system_monospace_font ();
 	if (font_desc) {
-            gtk_widget_override_font (priv->forecast_text, font_desc);
+            override_widget_font (priv->forecast_text, font_desc);
             pango_font_description_free (font_desc);
 	}
 
