@@ -335,17 +335,11 @@ void menu_preferences_cb(GtkAction *action, StickyNotesApplet *applet)
 void menu_help_cb(GtkAction *action, StickyNotesApplet *applet)
 {
 	GError *error = NULL;
-#if GTK_CHECK_VERSION (3, 22, 0)
+
 	gtk_show_uri_on_window (NULL,
 	                        "help:mate-stickynotes-applet",
 	                        gtk_get_current_event_time (),
 	                        &error);
-#else
-	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (applet->w_applet)),
-	              "help:mate-stickynotes-applet",
-	              gtk_get_current_event_time (),
-	              &error);
-#endif
 	if (error) {
 		GtkWidget *dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
 							   _("There was an error displaying help: %s"), error->message);
@@ -368,20 +362,25 @@ menu_about_cb (GtkAction *action,
 		NULL
 	};
 
-	char copyright[] = \
-		"Copyright \xc2\xa9 2012-2018 MATE developers\n"
-		"Copyright \xc2\xa9 2005 Davyd Madeley\n"
-		"Copyright \xc2\xa9 2002-2003 Loban A Rahman";
-
 	static const gchar *documenters[] = {
 		"Loban A Rahman <loban@earthling.net>",
-		"Sun GNOME Documentation Team <gdocteam@sun.com>",
+		N_("Sun GNOME Documentation Team <gdocteam@sun.com>"),
+		N_("MATE Documentation Team"),
 		NULL
 	};
 
+#ifdef ENABLE_NLS
+	const char **p;
+	for (p = documenters; *p; ++p)
+		*p = _(*p);
+#endif
+
 	gtk_show_about_dialog (NULL,
+		"title",        _("About Sticky Notes"),
 		"version",	VERSION,
-		"copyright",	copyright,
+		"copyright",	_("Copyright \xc2\xa9 2002-2003 Loban A Rahman\n"
+				  "Copyright \xc2\xa9 2005 Davyd Madeley\n"
+				  "Copyright \xc2\xa9 2012-2019 MATE developers"),
 		"comments",	_("Sticky Notes for the "
 				  "MATE Desktop Environment"),
 		"authors",	authors,
@@ -531,17 +530,11 @@ void preferences_response_cb(GtkWidget *dialog, gint response, gpointer data)
 {
 	if (response == GTK_RESPONSE_HELP) {
 		GError *error = NULL;
-#if GTK_CHECK_VERSION (3, 22, 0)
+
 		gtk_show_uri_on_window (GTK_WINDOW (dialog),
 		                        "help:mate-stickynotes-applet/stickynotes-advanced-settings",
 		                        gtk_get_current_event_time (),
 		                        &error);
-#else
-		gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (dialog)),
-		              "help:mate-stickynotes-applet/stickynotes-advanced-settings",
-		              gtk_get_current_event_time (),
-		              &error);
-#endif
 		if (error) {
 			dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
 								   _("There was an error displaying help: %s"), error->message);
