@@ -416,19 +416,24 @@ trash_applet_show_about (GtkAction   *action,
     NULL
   };
 
-  char copyright[] = \
-    "Copyright \xc2\xa9 2012-2018 MATE developers\n"
-    "Copyright \xc2\xa9 2008 Ryan Lortie\n"
-    "Copyright \xc2\xa9 2004 Michiel Sikkes";
-
   static const char *documenters[] = {
     "Michiel Sikkes <michiel@eyesopened.nl>",
+    N_("MATE Documentation Team"),
     NULL
   };
 
+#ifdef ENABLE_NLS
+  const char **p;
+  for (p = documenters; *p; ++p)
+    *p = _(*p);
+#endif
+
   gtk_show_about_dialog (NULL,
+                         "title", _("About Trash Applet"),
                          "version", VERSION,
-                         "copyright", copyright,
+                         "copyright", _("Copyright \xc2\xa9 2004 Michiel Sikkes\n"
+                                        "Copyright \xc2\xa9 2008 Ryan Lortie\n"
+                                        "Copyright \xc2\xa9 2012-2019 MATE developers"),
                          "comments", _("A MATE trash bin that lives in your panel. "
                                        "You can use it to view the trash or drag "
                                        "and drop items into the trash."),
@@ -583,10 +588,8 @@ trash_applet_drag_data_received (GtkWidget        *widget,
         }
     }
 
-  g_list_foreach (untrashable, (GFunc)g_object_unref, NULL);
-  g_list_free (untrashable);
-  g_list_foreach (trashed, (GFunc)g_object_unref, NULL);
-  g_list_free (trashed);
+  g_list_free_full (untrashable, g_object_unref);
+  g_list_free_full (trashed, g_object_unref);
 
   g_strfreev (list);
 
